@@ -5,7 +5,9 @@ from .data import Settings
 
 
 class TK211(CheckerBase):
-    message = "Using `import tkinter.ttk as ttk` is pointless. Use `from tkinter import ttk` instead."
+    message = (
+        "Using `import tkinter.ttk as ttk` is pointless. Use `from tkinter import ttk` instead."
+    )
 
     @staticmethod
     def detect() -> bool:
